Nameko
######

.. image:: https://secure.travis-ci.org/onefinestay/nameko.png?branch=master
   :target: http://travis-ci.org/onefinestay/nameko

**Nameko** ``[nah-meh-koh]`` (noun)

#. amber-brown mushroom with a slightly gelatinous coating that is used as an
   ingredient in miso soup and nabemono.
#. python framework for building service orientated software

Features:
---------

 * Quickly build, host and deploy services
 * Highly declarative, let's you concentrate on your business logic
 * RPC, Events (Pub-Sub) and AMQP Messaging out-of-the-box
 * Extensible, so you can write your own service interactions


Getting Started:
----------------

The best way to appreciate nameko's features is to use them in some simple
examples.  Follow the `getting started tutorial
<http://nameko.readthedocs.org/en/latest/#getting-started>`_ in the docs to do
just that.


Documentation:
--------------

Nameko is using Sphinx, and the latest documentation can be found here:

  http://nameko.readthedocs.org


Prerequisites:
--------------

Nameko requires an AMQP broker and is tested with
`RabbitMQ <http://http://www.rabbitmq.com/>`_.

The RabbitMQ `tutorials <http://www.rabbitmq.com/getstarted.html>`_ are very
good and serve as an excellent introduction to messaging and AMQP.


Installation:
-------------

Stable releases of nameko are available on the Python Package Index (
`PyPI <https://pypi.python.org/pypi/nameko>`_). Install it using ``pip`` or
``easy_install``:

 * pip install -U nameko
 * easy_install -U nameko


Contributing:
-------------

Nameko is developed on GitHub, primarily by the development team at 
`onefinestay <http://www.onefinestay.com>`_. The GitHub repository is
https://github.com/onefinestay/nameko.

You are welcome and encouraged to contribute comments, suggestions, patches
and feature requests.


License:
--------

Apache 2.0. See LICENSE for details.
